# Aurora-SE CLI Overview

Command guides are organized by domain:

- [shell](shell.md)
- [autopilot](autopilot.md)
- [plugins](plugins.md)
- [workspace](workspace.md)
- [notify](notify.md)
- [policy](policy.md)
- [report](report.md)
- [telemetry](telemetry.md)
- [governance](governance.md)
